============
Applications
============

If analysis using orix forms a part of published work please cite the paper (`journal
<https://doi.org/10.1107/S1600576720011103>`_, `arXiv
<https://arxiv.org/abs/2001.02716>`_) and the package itself via the Zenodo DOI:
https://doi.org/10.5281/zenodo.3459662.

Below is a tentative list of works using orix.
If you think your work should be listed here, please raise an issue `on GitHub
<https://github.com/pyxem/orix>`__ or `contact the developers
<pyxem.team@gmail.com>`__.

2024
====
- I. MacLaren, E. Frutos-Myro, S. Zeltmann, C. Ophus, "A method for crystallographic
  mapping of an alpha-beta titanium alloy with nanometre resolution using scanning
  precession electron diffraction and open-source software libraries," *Journal of
  Microscopy*, 1-9 (2024).
  https://doi/10.1111/jmi.13275.

2022
====

- P. Harrison, X. Zhou, S. M. Das, P. Lhuissier, C. H. Liebscher, M. Herbig, W. Ludwig,
  E. F. Rauch, "Reconstructing Dual-Phase Nanometer Scale Grains within a Pearlitic
  Steel Tip in 3D through 4D-Scanning Precession Electron Diffraction Tomography and
  Automated Crystal Orientation Mapping," *Ultramicroscopy* 113536 (2022).
  https://doi.org/10.1016/j.ultramic.2022.113536.
- N. Cautaerts, P. Crout, H. W. Ånes, E. Prestat, J. Jeong, G. Dehm, C. H. Liebscher,
  "Free, flexible and fast: Orientation mapping using the multi-core and GPU-accelerated
  template matching capabilities in the python-based open source 4D-STEM analysis
  toolbox Pyxem," *Ultramicroscopy* 113517 (2022).
  https://doi.org/10.1016/j.ultramic.2022.113517.
  (arXiv: https://arxiv.org/abs/2111.07347.)

2020
====

- D. N. Johnstone, B. H. Martineau, P. Crout, P. A. Midgley, A. S. Eggeman,
  "Density-based clustering of crystal (mis)orientations and the orix Python library,"
  *Journal of Applied Crystallography* **53(5)** (2020).
  https://doi.org/10.1107/S1600576720011103.
  (arXiv: https://arxiv.org/abs/2001.02716).
